from django.db.models.query_utils import DeferredAttribute
from django.forms.models import model_to_dict

from ..backend import utils


class UpdateScriptsMixin(object):
    pass


class WooeyPy2Mixin(object):
    def __unicode__(self):
        return unicode(self.__str__())




from .django_urls import *
from django.urls import include, path

urlpatterns += [
    # path('admin/', include(admin.site.urls)),
    path('', include('wooey.urls')),
    path('', include('django.contrib.auth.urls')),
]



# Generated by Django 3.2.15 on 2022-08-03 22:24

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('wooey', '0044_change_script_parameter_choices_to_text'),
    ]

    operations = [
        migrations.AddField(
            model_name='scriptversion',
            name='created_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='created_script_version_set', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='scriptversion',
            name='modified_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='modified_script_version_set', to=settings.AUTH_USER_MODEL),
        ),
    ]
